@@ -26,15 +26,16 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QFutureWatcher>
 #include <QScopedPointer>
 #include <QtConcurrentRun>
+#include <QUrl>
+#include <QApplication>
+#include <QTemporaryFile>
+#include <QSaveFile>
 
 // KDE
-#include <KApplication>
 #include <KIO/CopyJob>
 #include <KIO/JobUiDelegate>
-#include <KLocale>
-#include <KSaveFile>
-#include <KTemporaryFile>
-#include <KUrl>
+#include <KLocalizedString>
+#include <KJobWidgets>
 
 // Local
 #include "documentloadedimpl.h"
@@ -45,17 +46,17 @@ namespace Gwenview
 struct SaveJobPrivate
 {
     DocumentLoadedImpl* mImpl;
-    KUrl mOldUrl;
-    KUrl mNewUrl;
+    QUrl mOldUrl;
+    QUrl mNewUrl;
     QByteArray mFormat;
-    QScopedPointer<KTemporaryFile> mTemporaryFile;
-    QScopedPointer<KSaveFile> mSaveFile;
+    QScopedPointer<QTemporaryFile> mTemporaryFile;
+    QScopedPointer<QSaveFile> mSaveFile;
     QScopedPointer<QFutureWatcher<void> > mInternalSaveWatcher;
 
     bool mKillReceived;
 };
 
-SaveJob::SaveJob(DocumentLoadedImpl* impl, const KUrl& url, const QByteArray& format)
+SaveJob::SaveJob(DocumentLoadedImpl* impl, const QUrl &url, const QByteArray& format)
 : d(new SaveJobPrivate)
 {
     d->mImpl = impl;
@@ -74,7 +75,7 @@ SaveJob::~SaveJob()
 void SaveJob::saveInternal()
 {
     if (!d->mImpl->saveInternal(d->mSaveFile.data(), d->mFormat)) {
-        d->mSaveFile->abort();
+        d->mSaveFile->cancelWriting();
         setError(UserDefinedError + 2);
         setErrorText(d->mImpl->document()->errorString());
     }
@@ -90,19 +91,21 @@ void SaveJob::doStart()
     if (d->mNewUrl.isLocalFile()) {
         fileName = d->mNewUrl.toLocalFile();
     } else {
-        d->mTemporaryFile.reset(new KTemporaryFile);
+        d->mTemporaryFile.reset(new QTemporaryFile);
         d->mTemporaryFile->setAutoRemove(true);
         d->mTemporaryFile->open();
         fileName = d->mTemporaryFile->fileName();
     }
 
-    d->mSaveFile.reset(new KSaveFile(fileName));
+    d->mSaveFile.reset(new QSaveFile(fileName));
 
-    if (!d->mSaveFile->open()) {
-        KUrl dirUrl = d->mNewUrl;
-        dirUrl.setFileName(QString());
+    if (!d->mSaveFile->open(QSaveFile::WriteOnly)) {
+        QUrl dirUrl = d->mNewUrl;
+        dirUrl = dirUrl.adjusted(QUrl::RemoveFilename);
+        dirUrl.setPath(dirUrl.path() + QString());
         setError(UserDefinedError + 1);
-        setErrorText(i18nc("@info", "Could not open file for writing, check that you have the necessary rights in <filename>%1</filename>.", dirUrl.pathOrUrl()));
+        setErrorText(xi18nc("@info", "Could not open file for writing, check that you have the necessary rights in <filename>%1</filename>.",
+                            dirUrl.toDisplayString()));
         emitResult();
         return;
     }
@@ -125,8 +128,9 @@ void SaveJob::finishSave()
         return;
     }
 
-    if (!d->mSaveFile->finalize()) {
-        setErrorText(i18nc("@info", "Could not overwrite file, check that you have the necessary rights to write in <filename>%1</filename>.", d->mNewUrl.pathOrUrl()));
+    if (!d->mSaveFile->commit()) {
+        setErrorText(xi18nc("@info", "Could not overwrite file, check that you have the necessary rights to write in <filename>%1</filename>.",
+                            d->mNewUrl.toString()));
         setError(UserDefinedError + 3);
         return;
     }
@@ -134,8 +138,8 @@ void SaveJob::finishSave()
     if (d->mNewUrl.isLocalFile()) {
         emitResult();
     } else {
-        KIO::Job* job = KIO::copy(KUrl::fromPath(d->mTemporaryFile->fileName()), d->mNewUrl);
-        job->ui()->setWindow(KApplication::kApplication()->activeWindow());
+        KIO::Job* job = KIO::copy(QUrl::fromLocalFile(d->mTemporaryFile->fileName()), d->mNewUrl);
+        KJobWidgets::setWindow(job, qApp->activeWindow());
         addSubjob(job);
     }
 }
@@ -148,12 +152,12 @@ void SaveJob::slotResult(KJob* job)
     }
 }
 
-KUrl SaveJob::oldUrl() const
+QUrl SaveJob::oldUrl() const
 {
     return d->mOldUrl;
 }
 
-KUrl SaveJob::newUrl() const
+QUrl SaveJob::newUrl() const
 {
     return d->mNewUrl;
 }
